Biolink
=======

Homepages
* https://biolink.github.io/biolink-model/ -- Biolink model
* https://biolink.github.io/biolinkml/ -- Biolink modeling language

Docs
* https://biolink.github.io/biolink-model/docs
* https://biolink.github.io/biolinkml/docs

Contact
* Chris Mungall cjmungall AT lbl DOT gov @cmungall
* Harold Solbrig @hsolbrig
